@@ -36,6 +36,7 @@ class Config:  # noqa: PLR0904
         '.dmypy.json',
         '.env',
         '.git',
+        '.github',
         '.gitignore',
         '.ipynb_checkpoints',
         '.mypy_cache/',
@@ -67,7 +68,6 @@ class Config:  # noqa: PLR0904
         'env.bak/',
         'examples',
         'htmlcov',
-        'media',
         'node_modules',
         'poetry.lock',
         'private.version',
@@ -348,6 +348,11 @@ class Config:  # noqa: PLR0904
         """Connection method: 'USB' or 'WIFI'."""
         return self.get('STREAM_USING', 'USB')
 
+    @property
+    def SHOW_NOTIFICATIONS(self) -> bool:
+        """Enable desktop notifications during compilation and deployment."""
+        return self.get('SHOW_NOTIFICATIONS', True)
+
     @property
     def ADB_PORT(self) -> int:
         """ADB TCP/IP port number."""
